// CUSheet.cpp : implementation file
//
// CrackUp version 1.0
// Copyright  1998 Ziff-Davis, Inc.
// First published in PC Magazine, US Edition, November 3, 1998
// Written by Bob Flanders and Gregory A. Wolking

#include "stdafx.h"
#include "crackup.h"
#include "RptPage.h"
#include "CfgPage.h"
#include "CUSheet.h"


#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

extern CDialog				*g_pRptWin;
extern BOOL					g_bQuickMode,
							g_bStopScanNow,
							g_bScanInProgress;
extern HWND					g_hMasterWindow;
extern CRITICAL_SECTION		g_csScanning;
extern CString				g_strMaxMsg;
extern WORD					g_wNDrivesSelected;

/////////////////////////////////////////////////////////////////////////////
// CCUSheet

IMPLEMENT_DYNAMIC(CCUSheet, CPropertySheet)

CCUSheet::CCUSheet(UINT nIDCaption, CWnd* pParentWnd, UINT iSelectPage)
	:CPropertySheet(nIDCaption, pParentWnd, iSelectPage)
{
	m_pCfgPage = NULL;
	m_pRptPage = NULL;
	m_pCfgPage = new CCfgPage;
	m_pRptPage = new CRptPage;
	AddPage(m_pRptPage);
	AddPage(m_pCfgPage);
}

CCUSheet::CCUSheet(LPCTSTR pszCaption, CWnd* pParentWnd, UINT iSelectPage)
	:CPropertySheet(pszCaption, pParentWnd, iSelectPage)
{
	m_pCfgPage = NULL;
	m_pRptPage = NULL;
	m_pCfgPage = new CCfgPage;
	m_pRptPage = new CRptPage;
	AddPage(m_pRptPage);
	AddPage(m_pCfgPage);
}

CCUSheet::~CCUSheet()
{
	if (m_pCfgPage)	delete m_pCfgPage;
	if (m_pRptPage)	delete m_pRptPage;
	g_pRptWin = NULL;
	if (g_bQuickMode)		// If we're in quick mode,
		::PostMessage(g_hMasterWindow, WM_COMMAND, ID_EXIT, 0);	// Tell main window to shut down.
}


BEGIN_MESSAGE_MAP(CCUSheet, CPropertySheet)
	//{{AFX_MSG_MAP(CCUSheet)
	//}}AFX_MSG_MAP
	ON_MESSAGE(MYWM_SCANCOMPLETE,	OnScanComplete)
	ON_MESSAGE(MYWM_UPDATETIMELEFT, OnUpdateTimeLeft)
	ON_MESSAGE(MYWM_SHOWWARNING,	OnShowWarning)
	ON_BN_CLICKED(IDC_cmdExit, OnExit)
END_MESSAGE_MAP()


/////////////////////////////////////////////////////////////////////////////
// CCUSheet message handlers

long CCUSheet::OnScanComplete(WPARAM, LPARAM)
{
	if (GetActiveIndex() == 0)
		SetActivePage(1);
	SetActivePage(0);
	return 0;
}

// Handles message posted by CCrackUpDlg::OnTimer()
long CCUSheet::OnUpdateTimeLeft(WPARAM, LPARAM)
{
	if (m_pCfgPage->m_hWnd)
		if (GetActiveIndex() == 1)			// If Configure page is active,
			m_pCfgPage->ShowTimeLeft();		// tell it to update its time display.
	return 0;
}

// Handles alert message posted by CheckLevels()
// This method ensures that if a background scan occurs while this window
// is open, the modal message box will be created by this window and the
// foreground thread, not the main window and the background thread.
// This ensures that the user can't activate this window until he 
// dismisses the warning message.
long CCUSheet::OnShowWarning(WPARAM, LPARAM)
{
	MessageBox(g_strMaxMsg,					// display a message box with
			"CrackUp Notice",				// this title
			MB_OK | MB_ICONEXCLAMATION		// and an exclamation
				 | MB_TOPMOST);				// put it on top.
	return 0;
}

BOOL CCUSheet::OnInitDialog() 
{
	BOOL bResult = CPropertySheet::OnInitDialog();
	if (!g_bQuickMode)					// Quick mode doesn't need the Quit button!
	{
		HWND hWnd;
		CRect rect1, rect2, rect3;

		hWnd = ::GetDlgItem(m_hWnd, IDHELP);	// Get handle to help button.
		::GetWindowRect(hWnd, &rect1);			// Get screen coords of help button.
		ScreenToClient(&rect1);					// Convert to client coords.
		GetClientRect(&rect3);					// Get client coords of our window.
		rect2 = rect1;							// Our button will be same size as the help button,
		rect2.left = (rect3.right - rect1.right);	// displayed at the opposite side
		rect2.right = rect2.left + rect1.Width();	// of the client area.
		// Note: The above works because the CPropertySheet constructor
		// automatically puts the Help button at the bottom-right corner of the
		// window.

		// Create our button.
		m_cmdExit.Create("&Quit CrackUp",		// Caption
			WS_VISIBLE | WS_CHILD | WS_TABSTOP,	// Style
			rect2,								// Position
			this,								// Parent window.
			IDC_cmdExit);						// Identifier.
		// Make sure it has the same font as the rest of the dialog.
		m_cmdExit.SetFont(GetFont());
	}
	return bResult;
}

// "Quit CrackUp" button.
void CCUSheet::OnExit()
{
	if (g_bScanInProgress)						// If a scan is running,
	{
		g_bStopScanNow = TRUE;					// tell it to stop
		EnterCriticalSection(&g_csScanning);	// and wait until it does.
		LeaveCriticalSection(&g_csScanning);
	}
	if (m_pCfgPage->m_bSettingsChanged)		// If settings have changed,
	{
		// Ask user if he wants to save them.
		if (MessageBox("Save settings?", "CrackUp Notice", MB_YESNO | MB_ICONQUESTION) == IDYES)
		{
			m_pCfgPage->m_bNoQueryScan = TRUE;	// Set flag so Configure Page knows not to ask about re-scanning drives.
			m_pCfgPage->OnApply();				// Tell configure page to save settings.
		}
	}
	EndDialog(IDCANCEL);			// Close this property sheet.
	::PostMessage(g_hMasterWindow, WM_COMMAND, ID_EXIT, 0);	// Tell main window to shut down.
}